diff --git a/modules/jenkins/files/slave_scripts/propose_translation_update.sh b/modules/jenkins/files/slave_scripts/propose_translation_update.sh
index 7a54585ab7..509958e27a 100755
--- a/modules/jenkins/files/slave_scripts/propose_translation_update.sh
+++ b/modules/jenkins/files/slave_scripts/propose_translation_update.sh
@@ -59,11 +59,12 @@ fi
 # Add all changed files to git
 git add $PROJECT/locale/*
 
 # Don't send files where the only things that have changed are the
 # creation date, the version number or comment lines.
 for f in `git diff --cached --name-only`
 do
-  if [ `git diff --cached $f |egrep -v "(POT-Creation-Date|Project-Id-Version|^\+{3}|^\-{3}|^[-+]#)" | egrep -c "^[\-\+]"` -eq 0 ]
+  if [ `git diff --cached $f |egrep -v "(POT-Creation-Date|Project-Id-Version|PO-Revision-Date|^\+{3}|^\-{3}|^[-+]#)" | egrep -c "^[\-\+]"` -eq 0 ]
   then
       git reset -q $f
       git checkout -- $f
@@ -59,11 +59,12 @@ fi
 git add $PROJECT/locale/*
 
-# Don't send files where the only things that have changed are the
-# creation date, the version number or comment lines.
+# Don't send files where the only things which have changed are the
+# creation date, the version number, the revision date, or comment
+# lines.
 for f in `git diff --cached --name-only`
 do
diff --git a/modules/jenkins/files/slave_scripts/propose_translation_update_manuals.sh b/modules/jenkins/files/slave_scripts/propose_translation_update_manuals.sh
index d3ef161782..eb7da86a94 100755
--- a/modules/jenkins/files/slave_scripts/propose_translation_update_manuals.sh
+++ b/modules/jenkins/files/slave_scripts/propose_translation_update_manuals.sh
@@ -95,10 +95,11 @@ do
 done
 
 # Don't send files where the only things which have changed are the
 # creation date, the version number or comment lines.
 for f in `git diff --cached --name-only`
 do
-  if [ `git diff --cached $f |egrep -v "(POT-Creation-Date|Project-Id-Version|^\+{3}|^\-{3}|^[-+]#)" | egrep -c "^[\-\+]"` -eq 0 ]
+  if [ `git diff --cached $f |egrep -v "(POT-Creation-Date|Project-Id-Version|PO-Revision-Date|^\+{3}|^\-{3}|^[-+]#)" | egrep -c "^[\-\+]"` -eq 0 ]
   then
       git reset -q $f
       git checkout -- $f
@@ -95,10 +95,11 @@ do
 
 # Don't send files where the only things which have changed are the
-# creation date, the version number or comment lines.
+# creation date, the version number, the revision date, or comment
+# lines.
 for f in `git diff --cached --name-only`
 do